************
Installation
************

Installation process differs from environment: Local machine, Production Server or Docker development.
All those information is in `README.rst <https://github.com/MySmile/sfchat/blob/master/README.rst#installation>`_.
